package main

import (
	"encoding/json"
	"fmt"
	"io"
	"log"
	"net/http"
	"os"
)

func main() {
	var root []root

	err := os.Mkdir("hoods", 0777)
	if err != nil {
		log.Panic(err)
	}

	req, err := http.NewRequest(http.MethodGet, "https://keyserver.freifunk-franken.de/v2/hoods.php", nil)
	if err != nil {
		log.Panic(err)
	}

	res, err := http.DefaultClient.Do(req)
	if err != nil {
		log.Panic(err)
	}

	body, err := io.ReadAll(res.Body)
	if err != nil {
		log.Panic(err)
	}

	err = json.Unmarshal(body, &root)
	if err != nil {
		log.Panic(err)
	}

	for _, h := range root {
		var hood Hood
		req, err := http.NewRequest(http.MethodGet, fmt.Sprintf("https://keyserver.freifunk-franken.de/v2/?hoodid=%d", h.Id), nil)
		if err != nil {
			log.Panic(err)
		}

		res, err := http.DefaultClient.Do(req)
		if err != nil {
			log.Panic(err)
		}

		body, err := io.ReadAll(res.Body)
		if err != nil {
			log.Panic(err)
		}

		err = json.Unmarshal(body, &hood)
		if err != nil {
			log.Panic(err)
		}

		if len(h.Polygons) == 0 {
			hood.Location = []HoodCoordinate{{Lat: h.Lat, Long: h.Long}}
		} else {
			hood.Location = []HoodCoordinate{}
			for _, p := range h.Polygons[0] {
				hood.Location = append(hood.Location, HoodCoordinate{Lat: p.Lat, Long: p.Long})
			}
		}

		b, err := json.MarshalIndent(hood, "", "    ")
		if err != nil {
			log.Panic(err)
		}

		err = os.WriteFile("hoods/"+hood.HoodInfo.Name+".json", b, 0666)
		if err != nil {
			log.Panic(err)
		}
	}
}
